var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { rest } from 'msw';
import * as SwaggerParser from '@apidevtools/swagger-parser';
import { createResponseResolver } from './response/createResponseResolver';
import { normalizeSwaggerUrl } from './utils/normalizeSwaggerUrl';
import { getServers } from './utils/getServers';
import { joinPaths } from './utils/url';
const parser = new SwaggerParser();
/**
 * Generates request handlers from the given OpenAPI V2/V3 document.
 */
export function fromOpenApi(document) {
    return __awaiter(this, void 0, void 0, function* () {
        const specification = yield parser.dereference(document);
        const handlers = Object.entries(specification.paths).reduce((handlers, [url, pathItem]) => {
            for (const key of Object.keys(pathItem)) {
                const method = key;
                if (method !== 'get' &&
                    method !== 'put' &&
                    method !== 'post' &&
                    method !== 'delete' &&
                    method !== 'options' &&
                    method !== 'head' &&
                    method !== 'patch') {
                    continue;
                }
                const operation = pathItem[method];
                if (!operation) {
                    continue;
                }
                const serverUrls = getServers(specification);
                serverUrls.forEach((baseUrl) => {
                    const path = normalizeSwaggerUrl(url);
                    const requestUrl = isAbsoluteUrl(baseUrl)
                        ? new URL(path, baseUrl).href
                        : joinPaths(path, baseUrl);
                    const handler = rest[method](requestUrl, createResponseResolver(operation));
                    handlers.push(handler);
                });
            }
            return handlers;
        }, []);
        return handlers;
    });
}
//
function isAbsoluteUrl(url) {
    try {
        new URL(url);
        return true;
    }
    catch (error) {
        return false;
    }
}
