import { getBodyTransformers } from './transformers/bodyTransformer';
import { getHeadersTransformers } from './transformers/headersTransformer';
export function createResponseResolver(operation) {
    return (req, res, ctx) => {
        // Treat the opeartions that don't describe any
        // responses as not implemented.
        if (operation.responses == null ||
            Object.keys(operation.responses || {}).length === 0) {
            return res(ctx.status(501));
        }
        // Get the response object from the schema.
        let responseObject;
        const explicitResponseStatus = req.url.searchParams.get('response');
        if (explicitResponseStatus) {
            const explicitResponse = operation.responses[explicitResponseStatus];
            if (!explicitResponse) {
                return res(ctx.status(501));
            }
            responseObject = explicitResponse;
        }
        else {
            const fallbackResponse = operation.responses['200'] ||
                operation.responses.default;
            if (!fallbackResponse) {
                return res();
            }
            responseObject = fallbackResponse;
        }
        // Response status.
        const responseStatus = explicitResponseStatus || '200';
        const transformers = [
            ctx.status(Number(responseStatus)),
            ...getHeadersTransformers(responseObject, req, ctx),
            ...getBodyTransformers(responseObject, req, ctx),
        ];
        return res(...transformers);
    };
}
