import { headersToObject } from 'headers-utils/lib';
import { evolveJsonSchema } from '../../schema/evolve';
import { toString } from '../../utils/toString';
export function getBodyTransformers(responseObject, req, ctx) {
    if (!('content' in responseObject && responseObject.content != null)) {
        return [];
    }
    const requestHeaders = headersToObject(req.headers);
    const acceptedMimeTypes = [].concat(requestHeaders.accept);
    const explicitContentType = acceptedMimeTypes[0];
    const explicitContentTypeRegexp = new RegExp(explicitContentType.replace(/\/+/g, '\\/').replace(/\*/g, '.+?'));
    const allContentTypes = Object.keys(responseObject.content);
    const contentType = allContentTypes.find((contentType) => {
        // Find the first declared response content type
        // that matches the "Accept" request header.
        // Keep in mind that values like "*/*" and "application/*"
        // are completely valid.
        return explicitContentTypeRegexp.test(contentType);
    }) || allContentTypes[0];
    const mediaTypeObject = responseObject.content[contentType];
    const body = (() => {
        if (mediaTypeObject.example) {
            return mediaTypeObject.example;
        }
        if (mediaTypeObject.examples) {
            const { value } = Object.values(mediaTypeObject.examples)[0];
            return value;
        }
        if (mediaTypeObject.schema) {
            return evolveJsonSchema(mediaTypeObject.schema);
        }
    })();
    const transformers = [
        ctx.set('Content-Type', contentType),
    ];
    if (body) {
        transformers.push(ctx.body(toString(body)));
    }
    return transformers;
}
